using System;
using Oxide.Core;
using Oxide.Core.Configuration;
using Oxide.Core.Libraries.Covalence;
using System.Collections.Generic;

namespace Oxide.Plugins
{
    [Info("SuicideCooldown", "M&B-Studios", "1.0.0")]
    [Description("Allows players to commit suicide using a configurable command")]
    public class SuicideCooldown : CovalencePlugin
    {
        private PluginConfig config;
        private Dictionary<string, DateTime> cooldowns;

        private class PluginConfig
        {
            public string SuicideCommand { get; set; }
            public int CooldownSeconds { get; set; }
            public string CooldownMessage { get; set; }
        }

        private void Init()
        {
            LoadConfig();
            cooldowns = new Dictionary<string, DateTime>();
            AddCovalenceCommand(config.SuicideCommand, nameof(SuicideCommand));
        }

        protected override void LoadDefaultConfig()
        {
            config = GetDefaultConfig();
            SaveConfig();
        }

        private PluginConfig GetDefaultConfig()
        {
            return new PluginConfig
            {
                SuicideCommand = "kill",
                CooldownSeconds = 180, // 180 Sekunden entsprechen 3 Minuten
                CooldownMessage = "You need to wait {0} seconds before using this command again."
            };
        }

        private void LoadConfig()
        {
            config = Config.ReadObject<PluginConfig>();

            if (config == null)
            {
                LoadDefaultConfig();
            }
        }

        private void SaveConfig()
        {
            Config.WriteObject(config, true);
        }

        private void SuicideCommand(IPlayer player, string command, string[] args)
        {
            DateTime lastUsage;
            if (cooldowns.TryGetValue(player.Id, out lastUsage))
            {
                TimeSpan cooldownTime = TimeSpan.FromSeconds(config.CooldownSeconds);
                TimeSpan timeSinceLastUsage = DateTime.Now - lastUsage;

                if (timeSinceLastUsage < cooldownTime)
                {
                    TimeSpan remainingTime = cooldownTime - timeSinceLastUsage;
                    string formattedMessage = string.Format(config.CooldownMessage, (int)remainingTime.TotalSeconds);
                    player.Message(formattedMessage);
                    return;
                }
            }

            player.Kill();
            cooldowns[player.Id] = DateTime.Now;
        }
    }
}
